@@ -1,7 +1,5 @@
 from django.apps import AppConfig
 
-from . import monkeys
-
 
 class AfipConfig(AppConfig):
     name = 'django_afip'
@@ -9,4 +7,5 @@ class AfipConfig(AppConfig):
     verbose_name = 'AFIP'
 
     def ready(self):
-        monkeys.patch_https_for_afip()
+        # Register app signals:
+        from django_afip import signals  # noqa: F401
