@@ -14,23 +14,23 @@ Including another URLconf
     2. Add a URL to urlpatterns:  url(r'^blog/', include(blog_urls))
 """
 from django.conf import settings
-from django.conf.urls import include, url
+from django.conf.urls import url
 from django.contrib import admin
 from django.views.static import serve
 
 from django_afip import views
 
 urlpatterns = [
-    url(r'^admin/', include(admin.site.urls)),
+    url(r'^admin/', admin.site.urls),
     url(
-        r'^invoices/pdf/(?P<pk>\d+)?$',
+        r'^invoices/pdf/(?P<pk>\d+)$',
         views.ReceiptPDFView.as_view(),
-        name='receipt_view',
+        name='receipt_displaypdf_view',
     ),
     url(
-        r'^invoices/html/(?P<pk>\d+)?$',
-        views.ReceiptHTMLView.as_view(),
-        name='receipt_view',
+        r'^invoices/pdf/(?P<pk>\d+)$',
+        views.ReceiptPDFDownloadView.as_view(),
+        name='receipt_pdf_view',
     ),
     url(
         r'^media/(?P<path>.*)$',
